﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using C1.Silverlight.Chart;
using C1.Silverlight.Chart.Extended;
using System.Windows.Data;

namespace Charting101SL_Final
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
            //clear default chart data
            c1Chart1.Reset(true);
            c1Chart1.BeginUpdate();

            //fill data array
            DataSeries ds1 = new DataSeries();
            double[] values = new double[25];
            for (int i = 0; i < 25; i++)
            {
                values[i] = i * 500;
            }
            ds1.ValuesSource = values;
            //c1Chart1.Data.Children.Add(ds1);

            //data binding
            Data d = new Data(); 
            var data = d.GetSalesData();
            c1Chart1.Data.ItemsSource = data;

            DataSeries ds2 = new DataSeries();
            ds2.Label = "Revenue";
            ds2.ChartType = ChartType.Column;
            ds2.ValueBinding = new Binding("Revenue");

            DataSeries ds3 = new DataSeries();
            ds3.Label = "Expense";
            ds3.ChartType = ChartType.LineSymbols;
            ds3.ValueBinding = new Binding("Expense");

            c1Chart1.Data.Children.Add(ds2);
            c1Chart1.Data.Children.Add(ds3);

            //add axix titles
            c1Chart1.View.AxisX.Title = "Date";
            c1Chart1.View.AxisY.Title = "Sales";
            c1Chart1.View.AxisY.AnnoFormat = "c2";
            c1Chart1.View.AxisX.Min = 0;

            //data label or tooltip
            ds2.PointLabelTemplate = (DataTemplate)Resources["datalabel"];
            ds3.PointTooltipTemplate = (DataTemplate)Resources["datalabel"];

            //add scroll bar
            c1Chart1.View.AxisX.Scale = 0.3;
            c1Chart1.View.AxisX.ScrollBar = new AxisScrollBar();

            //interaction
            ZoomAction za = new ZoomAction();
            c1Chart1.Actions.Add(za);

            //customize plot elements
            ds3.PlotElementLoaded += new EventHandler(ds1_PlotElementLoaded);

            //time axis
            c1Chart1.View.AxisX.IsTime = true;
            c1Chart1.View.AxisX.AnnoFormat = "d";
            c1Chart1.Data.ItemNames = (from r in data select r.Date.ToString("MMM-yy")).ToArray();

            c1Chart1.EndUpdate();
        }

        void ds1_PlotElementLoaded(object sender, EventArgs e)
        {
            var pe = (PlotElement)sender;

            //conditional formatting
            if (pe.GetType().Equals(typeof(DotSymbol)))
            {
                DataPoint dp = pe.DataPoint;
                if (dp.Value < 2000)
                {
                    pe.Fill = new SolidColorBrush(Colors.Red);
                }
            }

            if (pe != null && pe.DataPoint.PointIndex > -1)
            {
                pe.MouseEnter += new MouseEventHandler(pe_MouseEnter);
                pe.MouseLeave += new MouseEventHandler(pe_MouseLeave);
            }
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            //reset chart scale
            c1Chart1.View.AxisY.Scale = 1;
            c1Chart1.View.AxisX.Scale = 0.3;

            //SaveFileDialog sfd = new SaveFileDialog();
            //sfd.Filter = "Jpeg files (*.jpg)|*.jpg|Png files (*.png)|*.png";

            //if (sfd.ShowDialog() == true)
            //{
            //    using (var stream = sfd.OpenFile())
            //    {
            //        if (sfd.SafeFileName.EndsWith(".jpg"))
            //            c1Chart1.SaveImage(stream, ImageFormat.Jpeg);
            //        else
            //            c1Chart1.SaveImage(stream, ImageFormat.Png);
            //    }
            //}
        }

        void pe_MouseLeave(object sender, MouseEventArgs e)
        {
            AnimateDataPoint(sender as PlotElement, 1, 1);
        }

        void pe_MouseEnter(object sender, MouseEventArgs e)
        {
            AnimateDataPoint(sender as PlotElement, 3, 0.2);
        }

        void AnimateDataPoint(PlotElement plotElement, double scale, double duration)
        {
            //get/create scale transform for the PlotElement
            var st = plotElement.RenderTransform as ScaleTransform;
            if (st == null)
            {
                st = new ScaleTransform();
                plotElement.RenderTransform = st;
                plotElement.RenderTransformOrigin = new Point(0.5, 0.5);
            }
            //create Storyboard and attach it to transform
            var sb = new Storyboard();
            Storyboard.SetTarget(sb, st);
            //animate X and Y scales
            foreach (string prop in new string[] { "ScaleX", "ScaleY" })
            {
                var da = new DoubleAnimation();
                da.To = scale;
                da.Duration = new Duration(TimeSpan.FromSeconds(duration));
                da.SetValue(Storyboard.TargetPropertyProperty, new PropertyPath(prop));
                sb.Children.Add(da);
            }
            //start animation
            sb.Begin();
        }
    }
}
